@@ -150,9 +150,8 @@ class DB:
             condition_expression = " AND ".join(statements)
             # or item does not exist
             hashed_key_name = self._hash_name(key.name)
-            condition_expression = f"({condition_expression}) OR #{hashed_key_name}<>:{hashed_key_name}"
+            condition_expression = f"({condition_expression}) OR attribute_not_exists(#{hashed_key_name})"
             expression_names[f"#{hashed_key_name}"] = key.name
-            expression_values[f":{hashed_key_name}"] = key.value
             kwargs = {
                 **kwargs,
                 "ConditionExpression": condition_expression,
